@@ -6,6 +6,7 @@ import codecs
 import time
 import datetime
 import click
+import json
 from git import Repo
 from colorama import init
 from pathlib import Path
@@ -28,15 +29,15 @@ enUi = ['button', 'checkbox', 'field', 'column', 'area', 'box', 'role', 'user',
 # Configuração da API de tradução
 
 urlTrad = 'https://translate.yandex.net/api/v1.5/tr.json/translate'
-apiTradKey = 'trnsl.1.1.20200423T224754Z.c7c8ffe1eb46fb13.862b87f341a60e80ade11d71c970d3f2f1ebdcf9'
+apiTradKey = ''
 
 # Idioma fonte
 
-sourceLang = 'en'
+sourceLang = ''
 
 # Idiomas traduzidos
 
-targetLangs = ['es', 'pt']
+targetLangs = []
 
 # Diretório fonte
 
@@ -83,18 +84,20 @@ def ProcessFiles(sourceFile):
                 PrGreen('\n Traslating Markdown from ' + sourceLang + ' to ' + targetLangs[i])
                 if sourceLang[:2] == 'en':
                     slicedUi = re.split(r'(\{\{.*?\}\} [a-zA-Z]+)', sourceContent)
-                    slicedItalic = re.split(r'(\*.*?\* [a-zA-Z]+)', sourceContent)
-                    slicedBold = re.split(r'(\*\*.*?\*\* [a-zA-Z]+)', sourceContent)
                     for j in range(len(slicedUi)):
                         if re.fullmatch(r'\{\{.*?\}\} [a-zA-Z]+', slicedUi[j]) and re.search(r'(?<=\}\} ).+', slicedUi[j]).group().casefold() in enUi:
                             slicedUi[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedUi[j])[::-1])
+                    sourceContent = ''.join(slicedUi)
+                    slicedItalic = re.split(r'(\*.*?\* [a-zA-Z]+)', sourceContent)
                     for j in range(len(slicedItalic)):
                         if re.fullmatch(r'\*.*?\* [a-zA-Z]+', slicedItalic[j]) and re.search(r'(?<=\* ).+', slicedItalic[j]).group().casefold() in enUi:
                             slicedItalic[j] = ' '.join(re.split(r'(?<=\*) ', slicedItalic[j])[::-1])
+                    sourceContent = ''.join(slicedItalic)
+                    slicedBold = re.split(r'(\*\*.*?\*\* [a-zA-Z]+)', sourceContent)
                     for j in range(len(slicedBold)):
                         if re.fullmatch(r'\*\*.*?\*\* [a-zA-Z]+', slicedBold[j]) and re.search(r'(?<=\*\* ).+', slicedBold[j]).group().casefold() in enUi:
                             slicedBold[j] = ' '.join(re.split(r'(?<=\*\*) ', slicedBold[j])[::-1])
-                    sourceContent = ''.join(slicedUi)
+                    sourceContent = ''.join(slicedBold)
                 slicedApple = list(filter(lambda x: x != '' and x is not None, mdRegex.split(sourceContent)))
                 for piece in slicedApple:
                     if mdRegex.fullmatch(piece):
@@ -184,6 +187,9 @@ def PrLightPurple(skk):
 @click.group()
 def root():
     """Traslation of DocFX source code"""
+    global apiTradKey
+    global sourceLang
+    global targetLangs
     init()
     global workTree
     if sourceDir not in os.listdir():
@@ -200,16 +206,43 @@ def root():
         re.purge
         exit()
     modifiedUnstaged = repo.index.diff(None)
+
     try:
         modifiedStaged = repo.index.diff('HEAD')
     except:
         PrRed("HEAD could not be found!\n Please make the first commit.")
         re.purge
         exit()
+
     allModified = modifiedStaged + modifiedUnstaged
     untrackedSrc = [n for n in repo.untracked_files if n.split('/')[1:] in os.listdir(sourceDir)]
     workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + untrackedSrc
 
+    try:
+        with open('~/tradocs.config.json', 'r') as file:
+            configs = json.load(file)
+        print(configs)
+        apiTradKey = configs['TRANSLATOR_KEY']
+        sourceLang = configs['SOURCE']
+        targetLangs = configs['TARGET']
+    except:
+        print(" Hey firstcomer, welcome to Tradocs!\n Please set up a few things before proceeding...")
+        apiTradKey = input(' Please enter your Yandex.Translate API key: ')
+        sourceLang = input(' Enter the ISO 639-1 (two-letter code) identifier for the source language: ').lower()
+        targetLangs = input(' Enter the ISO 639-1 identifiers for the target languages, separated by space: ').lower().split(' ')
+        configs = {
+            'TRANSLATOR_KEY': apiTradKey,
+            'SOURCE': sourceLang,
+            'TARGET': targetLangs
+        }
+        with open('~/tradocs.config.json', 'w') as file:
+            json.dump(configs, file)
+
+@root.command()
+def config():
+    """Show and set configuration"""
+    exit()
+
 @root.command()
 def diff():
     """Translation of modified files (work tree)"""
@@ -228,7 +261,7 @@ def diff():
         for i in range(len(fls)):
             reqs += fls[i][0]
             chars += fls[i][1]
-        estimatedT = int(reqs*.7)
+        estimatedT = int(reqs*1.1)
         print('\n Target languages:\t\t\t' + ', '.join(targetLangs))
         print(' Total of calls to translation service:\t' + str(reqs))
         print(' Total of characters for translation:\t' + str(chars * len(targetLangs)))
@@ -331,7 +364,7 @@ def all():
             for i in range(len(fls)):
                 reqs += fls[i][0]
                 chars += fls[i][1]
-            estimatedT = int(reqs*.7)
+            estimatedT = int(reqs*1.1)
             print(' Total of source language characters:\t' + str(chars))
             print(' Total of files to be generated:\t' + str(nFls))
             print(' Total of calls to translation service:\t' + str(reqs))
